Welcome to ClientVPS Mirrors

Help for package mlt.docreg
Title: Most Likely Transformations: Documentation and Regression Tests
Version: 1.1-12
Date: 2025-12-01
Description: Additional documentation, a package vignette and regression tests for package mlt.
Depends: mlt (≥ 1.3-2)
Imports: numDeriv, stats, eha, multcomp (≥ 1.4-4), lattice, survival, flexsurv, truncreg
Suggests: variables, basefun, MASS, TH.data, knitr, prodlim, gridExtra, nnet, mgcv, HSAUR3, sandwich, grid, latticeExtra, colorspace, Matrix, AER, coin, gamlss.data, mlbench, tram (≥ 0.6-0), rms
VignetteBuilder: knitr
URL: http://ctm.R-forge.R-project.org
License: GPL-2
NeedsCompilation: no
Packaged: 2025-12-08 12:59:46 UTC; hothorn
Author: Torsten Hothorn ORCID iD [aut, cre]
Maintainer: Torsten Hothorn <Torsten.Hothorn@R-project.org>
Repository: CRAN
Date/Publication: 2025-12-08 15:40:02 UTC

Check Gradient and Hessian

Description

Check analytic gradient and hessian against their numerical approximation

Usage

checkGH(object, tol)

Arguments

object

an object of class mlt as returned by mlt

tol

tolerance, passed to all.equal.

Details

Computes the gradient and hessian analytically and numerically and compares the two. Warnings are suppressed for the numerical approximations as they are not aware of model constraints which might get violated.

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.